@@ -168,10 +168,11 @@ totem_pl_parser_add_pls_with_contents (TotemPlParser *parser,
 	TotemPlParserResult retval = TOTEM_PL_PARSER_RESULT_UNHANDLED;
 	GFile *base_file;
 	char **lines;
-	int i, num_entries;
+	guint i, num_entries;
 	char *playlist_title;
 	gboolean fallback;
 	GHashTable *entries;
+	guint found_entries;
 
 	entries = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
@@ -183,7 +184,7 @@ totem_pl_parser_add_pls_with_contents (TotemPlParser *parser,
 	playlist_title = NULL;
 
 	/* Ignore empty lines */
-	while (totem_pl_parser_line_is_empty (lines[i]) != FALSE)
+	while (lines[i] != NULL && totem_pl_parser_line_is_empty (lines[i]) != FALSE)
 		i++;
 
 	if (lines[i] == NULL
@@ -241,7 +242,8 @@ totem_pl_parser_add_pls_with_contents (TotemPlParser *parser,
 
 	retval = TOTEM_PL_PARSER_RESULT_SUCCESS;
 
-	for (i = 1; i <= num_entries; i++) {
+	found_entries = 0;
+	for (i = 1; found_entries < num_entries; i++) {
 		char *file_str, *title, *genre, *length;
 		char *file_key, *title_key, *genre_key, *length_key;
 		gint64 length_num;
@@ -265,6 +267,7 @@ totem_pl_parser_add_pls_with_contents (TotemPlParser *parser,
 
 		if (file_str == NULL)
 			continue;
+		found_entries++;
 
 		fallback = parse_data->fallback;
 		if (parse_data->recurse)
